@@ -100,12 +100,12 @@ void drawFrameAxes(InputOutputArray image, InputArray cameraMatrix, InputArray d
     CV_Assert(length > 0);
 
     // project axes points
-    vector<Point3f> axesPoints;
+    std::vector<Point3f> axesPoints;
     axesPoints.push_back(Point3f(0, 0, 0));
     axesPoints.push_back(Point3f(length, 0, 0));
     axesPoints.push_back(Point3f(0, length, 0));
     axesPoints.push_back(Point3f(0, 0, length));
-    vector<Point2f> imagePoints;
+    std::vector<Point2f> imagePoints;
     projectPoints(axesPoints, rvec, tvec, cameraMatrix, distCoeffs, imagePoints);
 
     // draw axes lines
@@ -120,7 +120,7 @@ bool solvePnP( InputArray opoints, InputArray ipoints,
 {
     CV_INSTRUMENT_REGION();
 
-    vector<Mat> rvecs, tvecs;
+    std::vector<Mat> rvecs, tvecs;
     int solutions = solvePnPGeneric(opoints, ipoints, cameraMatrix, distCoeffs, rvecs, tvecs, useExtrinsicGuess, (SolvePnPMethod)flags, rvec, tvec);
 
     if (solutions > 0)
@@ -298,8 +298,8 @@ bool solvePnPRansac(InputArray _opoints, InputArray _ipoints,
         return false;
     }
 
-    vector<Point3d> opoints_inliers;
-    vector<Point2d> ipoints_inliers;
+    std::vector<Point3d> opoints_inliers;
+    std::vector<Point2d> ipoints_inliers;
     opoints = opoints.reshape(3);
     ipoints = ipoints.reshape(2);
     opoints.convertTo(opoints_inliers, CV_64F);
@@ -420,7 +420,7 @@ int solveP3P( InputArray _opoints, InputArray _ipoints,
     else
         imgPts = imgPts.reshape(1, 2*imgPts.rows);
 
-    vector<double> reproj_errors(solutions);
+    std::vector<double> reproj_errors(solutions);
     for (size_t i = 0; i < reproj_errors.size(); i++)
     {
         Mat rvec;
@@ -710,7 +710,7 @@ static void solvePnPRefine(InputArray _objectPoints, InputArray _imagePoints,
         rvec0.convertTo(rvec, CV_64F);
         tvec0.convertTo(tvec, CV_64F);
 
-        vector<Point2d> ipoints_normalized;
+        std::vector<Point2d> ipoints_normalized;
         undistortPoints(ipoints, ipoints_normalized, cameraMatrix, distCoeffs);
         Mat sd = Mat(ipoints_normalized).reshape(1, npoints*2);
         Mat objectPoints0 = opoints.reshape(1, npoints);
@@ -804,7 +804,7 @@ int solvePnPGeneric( InputArray _opoints, InputArray _ipoints,
     Mat cameraMatrix = Mat_<double>(cameraMatrix0);
     Mat distCoeffs = Mat_<double>(distCoeffs0);
 
-    vector<Mat> vec_rvecs, vec_tvecs;
+    std::vector<Mat> vec_rvecs, vec_tvecs;
     if (flags == SOLVEPNP_EPNP || flags == SOLVEPNP_DLS || flags == SOLVEPNP_UPNP)
     {
         if (flags == SOLVEPNP_DLS)
@@ -829,7 +829,7 @@ int solvePnPGeneric( InputArray _opoints, InputArray _ipoints,
     }
     else if (flags == SOLVEPNP_P3P || flags == SOLVEPNP_AP3P)
     {
-        vector<Mat> rvecs, tvecs;
+        std::vector<Mat> rvecs, tvecs;
         solveP3P(opoints, ipoints, _cameraMatrix, _distCoeffs, rvecs, tvecs, flags);
         vec_rvecs.insert(vec_rvecs.end(), rvecs.begin(), rvecs.end());
         vec_tvecs.insert(vec_tvecs.end(), tvecs.begin(), tvecs.end());
@@ -1082,7 +1082,7 @@ int solvePnPGeneric( InputArray _opoints, InputArray _ipoints,
 
         for (size_t i = 0; i < vec_rvecs.size(); i++)
         {
-            vector<Point2d> projectedPoints;
+            std::vector<Point2d> projectedPoints;
             projectPoints(objectPoints, vec_rvecs[i], vec_tvecs[i], cameraMatrix, distCoeffs, projectedPoints);
             double rmse = norm(Mat(projectedPoints, false), imagePoints, NORM_L2) / sqrt(2*projectedPoints.size());
 
