@@ -44,7 +44,6 @@
 #if !(defined(_WIN32) || defined(WINCE))
 # include <pthread.h>
 #endif
-#include <assert.h>
 #include <algorithm>
 #include <limits>
 
@@ -68,6 +67,10 @@
 #ifndef CV_UNUSED  // Required for standalone compilation mode (OpenCV defines this in base.hpp)
 #define CV_UNUSED(name) (void)name
 #endif
+#ifndef CV_Assert  // Required for standalone compilation mode (OpenCV defines this in base.hpp)
+#include <assert.h>
+#define CV_Assert(expr) assert(expr)
+#endif
 
 #ifdef __cplusplus
 extern "C" {
@@ -405,7 +408,7 @@ static
 inline int _opencv_ffmpeg_interrupt_callback(void *ptr)
 {
     AVInterruptCallbackMetadata* metadata = (AVInterruptCallbackMetadata*)ptr;
-    assert(metadata);
+    CV_Assert(metadata);
 
     if (metadata->timeout_after_ms == 0)
     {
@@ -850,6 +853,7 @@ static void ffmpeg_log_callback(void *ptr, int level, const char *fmt, va_list v
     static bool skip_header = false;
     static int prev_level = -1;
     CV_UNUSED(ptr);
+    if (level>av_log_get_level()) return;
     if (!skip_header || level != prev_level) printf("[OPENCV:FFMPEG:%02d] ", level);
     vprintf(fmt, vargs);
     size_t fmt_len = strlen(fmt);
@@ -866,15 +870,21 @@ class InternalFFMpegRegister
 
     static void initLogger_()
     {
-    #ifndef NO_GETENV
+#ifndef NO_GETENV
         char* debug_option = getenv("OPENCV_FFMPEG_DEBUG");
-        if (debug_option != NULL)
+        char* level_option = getenv("OPENCV_FFMPEG_LOGLEVEL");
+        int level = AV_LOG_VERBOSE;
+        if (level_option != NULL)
         {
-            av_log_set_level(AV_LOG_VERBOSE);
+            level = atoi(level_option);
+        }
+        if ( (debug_option != NULL) || (level_option != NULL) )
+        {
+            av_log_set_level(level);
             av_log_set_callback(ffmpeg_log_callback);
         }
         else
-    #endif
+#endif
         {
             av_log_set_level(AV_LOG_ERROR);
         }
@@ -2106,7 +2116,7 @@ bool CvVideoWriter_FFMPEG::writeFrame( const unsigned char* data, int step, int
         }
     }
     else {
-        assert(false);
+        CV_Assert(false);
     }
 
     if( (width & -2) != frame_width || (height & -2) != frame_height || !data )
@@ -2158,7 +2168,7 @@ bool CvVideoWriter_FFMPEG::writeFrame( const unsigned char* data, int step, int
     }
 
     if ( c->pix_fmt != input_pix_fmt ) {
-        assert( input_picture );
+        CV_Assert( input_picture );
         // let input_picture point to the raw data buffer of 'image'
         _opencv_ffmpeg_av_image_fill_arrays(input_picture, (uint8_t *) data,
                        (AVPixelFormat)input_pix_fmt, width, height);
@@ -2200,17 +2210,13 @@ bool CvVideoWriter_FFMPEG::writeFrame( const unsigned char* data, int step, int
 /// close video output stream and free associated memory
 void CvVideoWriter_FFMPEG::close()
 {
-    // nothing to do if already released
-    if ( !picture )
-        return;
-
     /* no more frame to compress. The codec has a latency of a few
        frames if using B frames, so we get the last frames by
        passing the same picture again */
     // TODO -- do we need to account for latency here?
 
     /* write the trailer, if any */
-    if(ok && oc)
+    if (picture && ok && oc)
     {
 #if LIBAVFORMAT_BUILD < CALC_FFMPEG_VERSION(57, 0, 0)
         if (!(oc->oformat->flags & AVFMT_RAWPICTURE))
@@ -2234,32 +2240,34 @@ void CvVideoWriter_FFMPEG::close()
 
     // free pictures
 #if LIBAVFORMAT_BUILD > 4628
-    if( video_st->codec->pix_fmt != input_pix_fmt)
+    if (picture && video_st && video_st->codec->pix_fmt != input_pix_fmt)
 #else
-    if( video_st->codec.pix_fmt != input_pix_fmt)
+    if (picture && video_st && video_st->codec.pix_fmt != input_pix_fmt)
 #endif
     {
         if(picture->data[0])
             free(picture->data[0]);
         picture->data[0] = 0;
     }
-    av_free(picture);
+    av_freep(&picture);
 
-    if (input_picture)
-        av_free(input_picture);
+    av_freep(&input_picture);
 
-    /* close codec */
+    if (video_st && video_st->codec)
+    {
+        /* close codec */
 #if LIBAVFORMAT_BUILD > 4628
-    avcodec_close(video_st->codec);
+        avcodec_close(video_st->codec);
 #else
-    avcodec_close(&(video_st->codec));
+        avcodec_close(&(video_st->codec));
 #endif
+    }
 
-    av_free(outbuf);
+    av_freep(&outbuf);
 
     if (oc)
     {
-        if (!(fmt->flags & AVFMT_NOFILE))
+        if (fmt && !(fmt->flags & AVFMT_NOFILE))
         {
             /* close the output file */
 
@@ -2434,7 +2442,7 @@ bool CvVideoWriter_FFMPEG::open( const char * filename, int fourcc,
 #else
     oc = av_alloc_format_context();
 #endif
-    assert (oc);
+    CV_Assert (oc);
 
     /* set file name */
     oc->oformat = fmt;
